.. image:: https://circleci.com/gh/pensolve/pensolvetools.svg?style=svg
    :target: https://circleci.com/gh/pensolve/pensolvetools

.. image:: https://img.shields.io/pypi/v/pensolvetools.svg
   :target: https://pypi.python.org/pypi/pensolvetools
   :alt: PyPi version

.. image:: https://coveralls.io/repos/github/pensolve/pensolvetools/badge.svg
   :target: https://coveralls.io/github/pensolve/pensolvetools

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target: https://github.com/pensolve/pensolvetools/blob/master/LICENSE
    :alt: License


*************
pensolvetools
*************

Additional functions for Pensolve's conversion from Excel to Python code


